#
# spec file for package python-pytest-virtualenv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-pytest-virtualenv%{psuffix}
Version:        1.8.1
Release:        1.1
Summary:        Virtualenv fixture for pytest
License:        MIT
URL:            https://github.com/man-group/pytest-plugins
Source:         https://files.pythonhosted.org/packages/source/p/pytest-virtualenv/pytest-virtualenv-%{version}.tar.gz
# PATCH-FIX-OPENSUSE remove dependency on the external module virtualenv
Patch0:         remove_virtualenv.patch
%if %{with test}
BuildRequires:  %{python_module pytest-virtualenv = %{version}}
%endif
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-importlib-metadata
Requires:       python-pytest
Requires:       python-pytest-fixture-config
Requires:       python-pytest-shutil
BuildArch:      noarch
%python_subpackages

%description
Create a Python virtual environment in your test that cleans up on
teardown. The fixture has utility methods to install packages and list
what's installed.

%prep
%autosetup -p1 -n pytest-virtualenv-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
# Requires network access
%pytest -k 'not (test_installed_packages or test_install_)'
%endif

%if !%{with test}
%files %{python_files}
%doc CHANGES.md README.md
%license LICENSE
%{python_sitelib}/pytest_virtualenv.py
%pycache_only %{python_sitelib}/__pycache__/pytest_virtualenv*.pyc
%{python_sitelib}/pytest_virtualenv-%{version}.dist-info
%endif

%changelog
* Tue Feb  4 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.8.1:
  * Added default to install editable packages by using direct_url.json,
    if it exists
- Test with all Python versions.
* Mon Nov  4 2024 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed python-setuptools-git
* Tue Oct 22 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.8.0:
  * Drop support for Python 2 and <3.6, removing compatibility code.
  * Use stdlib unittest.mock instead of mock package.
  * Removed usage of path.py and path in favour of pathlib.
  * Modernised package.
  * Added delete_workspace parameter to VirtualEnv.
  * Removed extras_require.
- Switch to pyproject macros.
- No more greedy globs in %%files.
- Removed patches, included upstream:
  * remove_mock.patch
- Refreshed remove_virtualenv.patch
- Do not test with Python 3.12 and above due to an upstream bug.
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon Nov 15 2021 Steve Kowalik <steven.kowalik@suse.com>
- Inject multibuild to break up a build loop.
* Sun Dec 13 2020 Matej Cepl <mcepl@suse.com>
- We don't need to break Python 2.7
* Fri Dec 11 2020 Matej Cepl <mcepl@suse.com>
- Add remove_mock.patch to remove dependency on the external mock
  package (gh#man-group/pytest-plugins#168). Also add
  remove_virtualenv.patch to remove dependency on external
  virtualenv package.
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.0:
  * Support pytest 4
  * Support python 3.7
* Wed Feb 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by pytest-runner
